@@ -37,6 +37,15 @@ class ClientException(Exception):
         self.error_message = error_message
         self.more_info = more_info
 
+    def __repr__(self):
+        return (f'ClientException(status={self.status}, '
+                f'error_code="{self.error_code}", '
+                f'error_message="{self.error_message}", '
+                f'more_info={self.more_info})')
+
+    def __str__(self):
+        return f'{self.status} {self.error_message}'
+
 
 class Client:
 
@@ -118,6 +127,10 @@ class Client:
             )
         return resp
 
+    @staticmethod
+    def is_json(resp):
+        return 'application/json' in resp.headers.get('content-type', '')
+
     async def _request(self, method, url, **kwargs):
         if not url.startswith(self.prefix):
             url = self.prefix + url
@@ -129,12 +142,9 @@ class Client:
             raise ClientException(error_message=str(exc))
         try:
             resp.raise_for_status()
-            if 'application/json' in resp.headers.get('content-type', ''):
-                return resp.json()
-            else:
-                return resp.content
-        except httpx.HTTPStatusError:
-            err = Error(**resp.json())
+            return resp.json() if self.is_json(resp) else resp.content
+        except httpx.HTTPStatusError as exc:
+            err = Error(**resp.json()) if self.is_json(resp) else make_err(exc)
             logger.debug(err)
             raise ClientException(**err.dict())
 
@@ -219,15 +229,6 @@ class Client:
         await self.client.__aexit__(exc_type, exc_val, exc_tb)
 
 
-class ReducedRepresentation:
-    def __repr_args__(self: BaseModel) -> "ReprArgs":
-        return [
-            (key, value)
-            for key, value in self.__dict__.items()
-            if self.__fields__[key].field_info.extra.get("repr", True)
-        ]
-
-
 class Repository(BaseModel):
     type: str = Field(alias='RepositoryType', default=None)
     host: str = Field(alias='Host', default=None)
@@ -235,7 +236,7 @@ class Repository(BaseModel):
     path: str = Field(alias='Path', default=None)
 
 
-class File(ReducedRepresentation, BaseModel):
+class File(BaseModel):
     name: str = Field(alias='Name', default=None)
     content: bytes = Field(alias='Content', default=None, repr=False)
     size: int = Field(alias='Size', default=0)
@@ -347,3 +348,12 @@ class Error(BaseModel):
     error_code: str = Field(alias='ErrorCode')
     error_message: str = Field(alias='ErrorMessage')
     more_info: Optional[dict] = Field(alias='MoreInfo')
+
+
+def make_err(exc: httpx.HTTPStatusError):
+    return Error(**{
+        'HTTPStatus': exc.response.status_code,
+        'ErrorCode': 'INCORRECT_RESPONSE_CONTENT',
+        'ErrorMessage': exc.response.reason_phrase,
+        'MoreInfo': None
+    })
